==> pgmarket-1.2.2.tar.gz: pgmarket-1.2.2/shopping/search.php <==
<?

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
/* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */

include("../application.inc.php");

$stringtsf_stripped = ereg_replace ("\+", "", $stringtsf);

if (empty($stringtsf_stripped)) {
	header("Location: $CFG->wwwroot");
}

if (!isset($page_number) || $dbchanged) {
	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
	$SESSION["numr"] = db_num_rows($qid_p);
	for ($i=0; $i<$SESSION["numr"]; $i++) {
		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
	}
	if (!isset($page_number)) {
		$page_number = 1;
	}
}

$DOC_TITLE = $Shopping_Catalog;
$SESSION["goback"]["request_uri"] = $REQUEST_URI;
$SESSION["goback"]["query_string"] = $QUERY_STRING;
include("$CFG->templatedir"."header.ihtml");
if ($SESSION["numr"] > $SESSION["max_results"]) {
	include("templates/".$SESSION["lang"]."/too_many_results.ihtml");
} else if ($SESSION["numr"] > $SESSION["products_per_page"]) {
	$first = ($page_number-1)*$SESSION["products_per_page"];
	$last = $SESSION["numr"] < $page_number*$SESSION["products_per_page"] ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
	$num_pages = $SESSION["numr"] / $SESSION["products_per_page"];
	if (!($num_pages == (integer) $num_pages)) {
		$num_pages = (integer) $num_pages + 1;
	}
	include("templates/search_results.ihtml");
} else {
	$first = 0;
	$last = $SESSION["numr"] - 1;
	include("templates/search_results.ihtml");
}
include("$CFG->templatedir"."footer.ihtml");

?>

==> pgmarket-1.3.3.tar.gz: pgmarket-1.3.3/shopping/search.php <==
<?

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
/* (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua> */

include("../application.inc.php");

$stringtsf_stripped = ereg_replace ("\+", "", $stringtsf);

if (empty($stringtsf_stripped)) {
	header("Location: $CFG->firstpage");
}

if (!isset($page_number) || $dbchanged) {
	$qid_p = find_products(&$stringtsf_stripped, $case_sensitive, $concatenation);
	$SESSION["numr"] = db_num_rows($qid_p);
	for ($i=0; $i<$SESSION["numr"]; $i++) {
		$SESSION["searchres"][$i] = db_fetch_array($qid_p, $i);
	}
	if (!isset($page_number)) {
		$page_number = 1;
	}
}

$DOC_TITLE = $Shopping_Catalog;
$SESSION["goback"]["request_uri"] = $REQUEST_URI;
$SESSION["goback"]["query_string"] = $QUERY_STRING;
include("$CFG->templatedir"."header.ihtml");
if ($SESSION["numr"] > $SESSION["max_results"]) {
	include("templates/".$SESSION["lang"]."/too_many_results.ihtml");
} else if ($SESSION["numr"] > $SESSION["products_per_page"]) {
	$first = ($page_number-1)*$SESSION["products_per_page"];
	$last = $SESSION["numr"] < $page_number*$SESSION["products_per_page"] ? $SESSION["numr"]-1 : $page_number*$SESSION["products_per_page"]-1;
	$num_pages = $SESSION["numr"] / $SESSION["products_per_page"];
	if (!($num_pages == (integer) $num_pages)) {
		$num_pages = (integer) $num_pages + 1;
	}
	include("templates/search_results.ihtml");
} else {
	$first = 0;
	$last = $SESSION["numr"] - 1;
	include("templates/search_results.ihtml");
}
include("$CFG->templatedir"."footer.ihtml");

?>
